@@ -39,7 +39,7 @@ class SamplingScheduler(object):
         """
         # unique identifier for instance
         self._uuid = str(uuid.uuid4())
-
+        logger.debug(f'creating scheduler {self._uuid[:5]}')
         self.logger = logger.getChild(f'{self.__class__.__name__} {self._uuid[:5]}')
 
         # event control of killswitch for stop command
@@ -197,6 +197,7 @@ class SamplingScheduler(object):
     @property
     def default_actions(self) -> List[ConfiguredAction]:
         """list of default actions associated with the Scheduler"""
+        # todo have default actions at the scheduler class level
         return self._default_actions
 
     def _determine_actions(self,
@@ -545,7 +546,7 @@ class SamplingScheduler(object):
             'sampled_time_points': self.triggered_time_points,
             'remaining_time_points': self.remaining_time_points,
         }
-        if len(self.time_points) != 0:
+        if self.next_time_point is not None:
             out['next_time_point'] = self.next_time_point.time_delta
         if self._killswitch.is_set() is True:
             out['terminated'] = True
